@@ -23,7 +23,7 @@ class AppDataContainerFactory(dict):
 
     def __getattr__(self, name):
         if name.startswith('_') or self._app_registry.get_class(name, self._model) is None:
-            raise AttributeError()
+            raise AttributeError(name)
         return self[name]
 
     def __getitem__(self, name):
@@ -100,12 +100,14 @@ class AppDataContainer(object):
         self._accessed = False
         self._instance = model_instance
 
+    def __repr__(self):
+        return '<%s: %r>' % (self.__class__.__name__, self.serialize())
+
     def __eq__(self, other):
         if isinstance(other, AppDataContainer):
-            #FIXME: _attr_cache
-            return self._data == other._data
+            return self.serialize() == other.serialize()
         elif isinstance(other, dict):
-            return other == self._data
+            return other == self.serialize()
         return False
 
     @property
@@ -137,10 +139,12 @@ class AppDataContainer(object):
 
         # defined field, still uncleaned, retrieve from self._form and put in cache
         if name in self._form.fields and name not in self._attr_cache:
-            if name in self._data:
-                self._attr_cache[name] = self._form.fields[name].clean(self._data[name])
-            else:
-                self._attr_cache[name] = self._form.fields[name].initial
+            field = self._form.fields[name]
+            # we want to invoke clean, even on initial values. otherwise it's
+            # quite inelegant to work with collection types like lists, as
+            # initial=[] will lead to a single list instance being used for all
+            # instances.
+            self._attr_cache[name] = field.clean(self._data.get(name, field.initial))
 
         # defined field stored in cache, return it
         if name in self._attr_cache:
@@ -151,11 +155,11 @@ class AppDataContainer(object):
     def __getattr__(self, name):
         " Provide access to fields as attributes. "
         if name.startswith('_'):
-            raise AttributeError()
+            raise AttributeError(name)
         try:
             return self.__getitem__(name)
         except KeyError:
-            raise AttributeError()
+            raise AttributeError(name)
 
     def __delitem__(self, name):
         self._accessed = True
@@ -168,9 +172,7 @@ class AppDataContainer(object):
         try:
             return self[name]
         except KeyError:
-            if default is INITIAL and name in self._form.fields:
-                return self._form.fields[name].initial
-            elif default is INITIAL:
+            if default is INITIAL:
                 return None
             return default
 
