@@ -1,10 +1,10 @@
 from django.contrib.admin import site
 
-from app_data.admin import AppDataModelAdmin, AddDataTabularInline
+from app_data.admin import AppDataModelAdmin, AppDataTabularInline
 
 from .models import Article, Author
 
-class AuthorInline(AddDataTabularInline):
+class AuthorInline(AppDataTabularInline):
     model = Author
     declared_fieldsets = [
         ('Personal', {'fields': [('personal.first_name', 'personal.last_name')]})
